This is the mail archive of the glibc-cvs@sourceware.org mailing list for the glibc project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

GNU C Library master sources branch, master, updated. glibc-2.11-302-g8f4a504


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "GNU C Library master sources".

The branch, master has been updated
       via  8f4a5048eea6536ee85c0f2670adbb97d71e427d (commit)
       via  0a164fe03ee79d93e5dd2b1e1917e4ff5d580e1f (commit)
       via  b9ea2dd05ee1684ca36ce7ee62ac679f391b6a7f (commit)
       via  a5f3b0f830920ae31e24cad8fe5d877bba556764 (commit)
       via  463ed2f0bee56eb61a83b401a0134a4b8955178a (commit)
      from  62f8db6e495ccc77d2f4a0e37406ae97d2ccfd3c (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
http://sources.redhat.com/git/gitweb.cgi?p=glibc.git;a=commitdiff;h=8f4a5048eea6536ee85c0f2670adbb97d71e427d

commit 8f4a5048eea6536ee85c0f2670adbb97d71e427d
Author: Ulrich Drepper <drepper@redhat.com>
Date:   Sat Mar 27 06:19:50 2010 -0700

    Optimize __getpagesize a bit.

diff --git a/ChangeLog b/ChangeLog
index d06b956..4587248 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,5 +1,8 @@
 2010-03-27  Ulrich Drepper  <drepper@redhat.com>
 
+	* sysdeps/unix/sysv/linux/getpagesize.c (__getpagesize): If
+	__ASSUME_AT_PAGESIZE we can rely on the value being set.
+
 	* include/wchar.h: Undefine __need_mbstate_t and __need_wint_t
 	unconditionally in the end.
 
diff --git a/sysdeps/unix/sysv/linux/getpagesize.c b/sysdeps/unix/sysv/linux/getpagesize.c
index 6d03b3b..0866079 100644
--- a/sysdeps/unix/sysv/linux/getpagesize.c
+++ b/sysdeps/unix/sysv/linux/getpagesize.c
@@ -1,4 +1,4 @@
-/* Copyright (C) 1991,1992,1995-1997,2000,2002,2004
+/* Copyright (C) 1991,1992,1995-1997,2000,2002,2004,2010
    Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
@@ -17,30 +17,37 @@
    Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
    02111-1307 USA.  */
 
+#include <assert.h>
 #include <unistd.h>
 #include <sys/param.h>
 
 #include <ldsodefs.h>
+#include <kernel-features.h>
 
 /* Return the system page size.  */
 int
 __getpagesize ()
 {
+#ifdef __ASSUME_AT_PAGESIZE
+  assert (GLRO(dl_pagesize) != 0);
+  return GLRO(dl_pagesize);
+#else
   if (GLRO(dl_pagesize) != 0)
     return GLRO(dl_pagesize);
 
-#ifdef	EXEC_PAGESIZE
+# ifdef	EXEC_PAGESIZE
   return EXEC_PAGESIZE;
-#else	/* No EXEC_PAGESIZE.  */
-#ifdef	NBPG
-#ifndef	CLSIZE
-#define	CLSIZE	1
-#endif	/* No CLSIZE.  */
+# else	/* No EXEC_PAGESIZE.  */
+#  ifdef NBPG
+#   ifndef CLSIZE
+#    define CLSIZE	1
+#   endif	/* No CLSIZE.  */
   return NBPG * CLSIZE;
-#else	/* No NBPG.  */
+#  else	/* No NBPG.  */
   return NBPC;
-#endif	/* NBPG.  */
-#endif	/* EXEC_PAGESIZE.  */
+#  endif	/* NBPG.  */
+# endif	/* EXEC_PAGESIZE.  */
+#endif
 }
 libc_hidden_def (__getpagesize)
 weak_alias (__getpagesize, getpagesize)

http://sources.redhat.com/git/gitweb.cgi?p=glibc.git;a=commitdiff;h=0a164fe03ee79d93e5dd2b1e1917e4ff5d580e1f

commit 0a164fe03ee79d93e5dd2b1e1917e4ff5d580e1f
Author: Ulrich Drepper <drepper@redhat.com>
Date:   Sat Mar 27 06:19:03 2010 -0700

    Whitespace fixes.

diff --git a/posix/glob.c b/posix/glob.c
index e410d50..6df083a 100644
--- a/posix/glob.c
+++ b/posix/glob.c
@@ -1042,9 +1042,9 @@ glob (pattern, flags, errfunc, pglob)
 	     : (__stat64 (pglob->gl_pathv[i], &st64) == 0
 		&& S_ISDIR (st64.st_mode))))
 	  {
- 	    size_t len = strlen (pglob->gl_pathv[i]) + 2;
+	    size_t len = strlen (pglob->gl_pathv[i]) + 2;
 	    char *new = realloc (pglob->gl_pathv[i], len);
- 	    if (new == NULL)
+	    if (new == NULL)
 	      {
 		globfree (pglob);
 		pglob->gl_pathc = 0;

http://sources.redhat.com/git/gitweb.cgi?p=glibc.git;a=commitdiff;h=b9ea2dd05ee1684ca36ce7ee62ac679f391b6a7f

commit b9ea2dd05ee1684ca36ce7ee62ac679f391b6a7f
Author: Ulrich Drepper <drepper@redhat.com>
Date:   Sat Mar 27 06:06:35 2010 -0700

    Fix handling of __need_mbstate_t and __need_wint_t.
    
    Like the real header, the libc-internal wrapper for wchar.h needs to
    undefine the macros so that if the header was already included before
    the macros don't stay defined and cause problems later.

diff --git a/ChangeLog b/ChangeLog
index 0969ca2..d06b956 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,5 +1,8 @@
 2010-03-27  Ulrich Drepper  <drepper@redhat.com>
 
+	* include/wchar.h: Undefine __need_mbstate_t and __need_wint_t
+	unconditionally in the end.
+
 	* posix/glob.c (glob): Initialize oldcount early, too.
 
 2010-03-26  Ulrich Drepper  <drepper@redhat.com>
diff --git a/include/wchar.h b/include/wchar.h
index bca8477..3afe0b6 100644
--- a/include/wchar.h
+++ b/include/wchar.h
@@ -195,3 +195,8 @@ extern size_t __mbsrtowcs_l (wchar_t *dst, const char **src, size_t len,
 
 # endif
 #endif
+
+/* Undefine all __need_* constants in case we are included to get those
+   constants but the whole file was already read.  */
+#undef __need_mbstate_t
+#undef __need_wint_t

http://sources.redhat.com/git/gitweb.cgi?p=glibc.git;a=commitdiff;h=a5f3b0f830920ae31e24cad8fe5d877bba556764

commit a5f3b0f830920ae31e24cad8fe5d877bba556764
Author: Ulrich Drepper <drepper@redhat.com>
Date:   Sat Mar 27 05:48:17 2010 -0700

    Fix one more issue with the glob patch.

diff --git a/ChangeLog b/ChangeLog
index d020871..0969ca2 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,7 @@
+2010-03-27  Ulrich Drepper  <drepper@redhat.com>
+
+	* posix/glob.c (glob): Initialize oldcount early, too.
+
 2010-03-26  Ulrich Drepper  <drepper@redhat.com>
 
 	* sysdeps/unix/sysv/linux/i386/fcntl.c: Define miss_F_GETOWN_EX
diff --git a/posix/glob.c b/posix/glob.c
index 3ae055d..e410d50 100644
--- a/posix/glob.c
+++ b/posix/glob.c
@@ -436,6 +436,8 @@ glob (pattern, flags, errfunc, pglob)
 	}
     }
 
+  oldcount = pglob->gl_pathc + pglob->gl_offs;
+
   /* Find the filename.  */
   filename = strrchr (pattern, '/');
 #if defined __MSDOS__ || defined WINDOWS32
@@ -553,8 +555,6 @@ glob (pattern, flags, errfunc, pglob)
 	}
     }
 
-  oldcount = pglob->gl_pathc + pglob->gl_offs;
-
 #ifndef VMS
   if ((flags & (GLOB_TILDE|GLOB_TILDE_CHECK)) && dirname[0] == '~')
     {

http://sources.redhat.com/git/gitweb.cgi?p=glibc.git;a=commitdiff;h=463ed2f0bee56eb61a83b401a0134a4b8955178a

commit 463ed2f0bee56eb61a83b401a0134a4b8955178a
Author: Ulrich Drepper <drepper@redhat.com>
Date:   Sat Mar 27 04:48:18 2010 -0700

    Fix comments and indentation.

diff --git a/sysdeps/unix/sysv/linux/kernel-features.h b/sysdeps/unix/sysv/linux/kernel-features.h
index f48e644..275668b 100644
--- a/sysdeps/unix/sysv/linux/kernel-features.h
+++ b/sysdeps/unix/sysv/linux/kernel-features.h
@@ -1,6 +1,6 @@
 /* Set flags signalling availability of kernel features based on given
    kernel version number.
-   Copyright (C) 1999-2006, 2007, 2008, 2009 Free Software Foundation, Inc.
+   Copyright (C) 1999-2009, 2010 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -65,7 +65,7 @@
 # define __ASSUME_LCHOWN_SYSCALL	1
 #endif
 
 /* When did the `setresuid' sysall became available?  */
 #if __LINUX_KERNEL_VERSION >= 131584 && !defined __sparc__
 # define __ASSUME_SETRESUID_SYSCALL	1
 #endif
@@ -126,7 +126,7 @@
 #endif
 
 /* I know for sure that these are in 2.3.35 on powerpc. But PowerPC64 does not
-   support separate 64-bit syscalls, already 64-bit */
+   support separate 64-bit syscalls, already 64-bit.  */
 #if __LINUX_KERNEL_VERSION >= 131875 && defined __powerpc__ \
     && !defined __powerpc64__
 # define __ASSUME_TRUNCATE64_SYSCALL	1
@@ -158,8 +158,8 @@
 # define __ASSUME_LDT_WORKS		1
 #endif
 
-/* Linux 2.4.0 on PPC introduced a correct IPC64. But PowerPC64 does not
-   support a separate 64-bit sys call, already 64-bit */
+/* Linux 2.4.0 on PPC introduced a correct IPC64.  But PowerPC64 does not
+   support a separate 64-bit syscall, already 64-bit.  */
 #if __LINUX_KERNEL_VERSION >= 132096 && defined __powerpc__ \
     && !defined __powerpc64__
 # define __ASSUME_IPC64			1
@@ -208,7 +208,7 @@
 # define __ASSUME_GETDENTS64_SYSCALL	1
 #endif
 
-/* When did O_DIRECTORY became available?  Early in 2.3 but when?
+/* When did O_DIRECTORY become available?  Early in 2.3 but when?
    Be safe, use 2.3.99.  */
 #if __LINUX_KERNEL_VERSION >= 131939
 # define __ASSUME_O_DIRECTORY		1
@@ -412,7 +412,7 @@
 
 /* Starting with version 2.6.9, SSI_IEEE_RAISE_EXCEPTION exists.  */
 #if __LINUX_KERNEL_VERSION >= 0x020609 && defined __alpha__
-#define __ASSUME_IEEE_RAISE_EXCEPTION	1
+# define __ASSUME_IEEE_RAISE_EXCEPTION	1
 #endif
 
 /* On sparc64 stat64/lstat64/fstat64 syscalls were introduced in 2.6.12.  */

-----------------------------------------------------------------------

Summary of changes:
 ChangeLog                                 |   10 ++++++++++
@@ -65,7 +65,7 @@
 #endif
 
-/* When did the `setresuid' sysall became available?  */
+/* When did the `setresuid' syscall became available?  */
 #if __LINUX_KERNEL_VERSION >= 131584 && !defined __sparc__
 # define __ASSUME_SETRESUID_SYSCALL	1
 include/wchar.h                           |    5 +++++
 posix/glob.c                              |    8 ++++----
 sysdeps/unix/sysv/linux/getpagesize.c     |   27 +++++++++++++++++----------
 sysdeps/unix/sysv/linux/kernel-features.h |   14 +++++++-------
 5 files changed, 43 insertions(+), 21 deletions(-)


hooks/post-receive
-- 
GNU C Library master sources


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]